@@ -9,7 +9,8 @@
 * `alt_stacked_area`,`alt_stacked_area_facets`: stacked area plots
 * `plot_parameterized_estimates`: plots densities of estimates of coefficients, with the true values,  as a function of a parameter
 * `plot_true_sim_facets, plot_true_sim2_facets`:  plot two simulated values and  the true values of statistics as a function of a parameter
-* `alt_tick_plots`: vertically arranged tick plots of variables.
+* `alt_tick_plots`: vertically arranged tick plots of variables
+* `alt_matrix_heatmap`: plots a heatmap of a matrix.
 """
 
 from typing import Callable, cast
@@ -126,6 +127,47 @@ def alt_scatterplot(
     return ch
 
 
+def alt_boxes(
+    df: pd.DataFrame,
+    continuous_var: str,
+    discrete_var: str,
+    group_var: str,
+    max_cols: int = 3,
+    title: str | None = None,
+    save: str | None = None,
+) -> alt.Chart:
+    """horizontal boxplots of `df[continuous_var]` by `df[discrete_var]` and `df[group_var]`
+
+    Args:
+        df: datframe with the three variables
+        continuous_var: name of the continuous variable
+        discrete_var: name of the discrete variable
+        group_var: name of the grouping variable
+        max_cols: maximum number of columns. Defaults to 3.
+        title: a plot title. Defaults to None.
+        save: the name of a file to save to (HTML extension will be added). Defaults to None.
+
+    Returns:
+        the chart.
+    """
+    boxes = (
+        (
+            alt.Chart(df)
+            .mark_boxplot()
+            .encode(
+                x=f"{continuous_var}:Q", y=f"{discrete_var}:O", color=f"{group_var}:N"
+            )
+            .properties(width=180, height=180)
+        )
+        .facet(f"{group_var}:N", columns=max_cols)
+        .resolve_scale(y="independent")
+    )
+    if title:
+        boxes = boxes.properties(title=title)
+    _maybe_save(boxes, save)
+    return boxes
+
+
 def alt_lineplot(
     df: pd.DataFrame,
     str_x: str,
@@ -155,10 +197,79 @@ def alt_lineplot(
     ch = alt.Chart(df).mark_line().encode(x=f"{str_x}:{type_x}", y=var_y)
     if "title" in kwargs:
         ch = ch.properties(title=kwargs["title"])
-        _maybe_save(ch, save)
+    _maybe_save(ch, save)
     return ch
 
 
+def alt_matrix_heatmap(
+    mat: np.ndarray,
+    str_format: str,
+    multiple: float = 1.0,
+    title: str | None = None,
+    str_rows: str | None = "Row",
+    str_cols: str | None = "Column",
+    save: str | None = None,
+) -> alt.Chart:
+    """Plots a heatmap of a matrix
+
+    Args:
+        mat: the matrix to plot
+        str_format: the string to format the values, e.g. "d" or ".3f"
+        multiple: increases the size of the circles
+        title: a title, if any
+        str_rows: the name of the variable in the rows
+        str_cols: the name of the variable in the columns
+        save: the name of a file to save to (HTML extension will be added)
+
+    Returns:
+        the heatmap
+    """
+    n_rows, n_cols = check_matrix(mat)
+    mat_arr = np.empty((mat.size, 4))
+    type_vals = "float"
+    if "d" in str_format:  # integer values
+        mat = np.round(mat)
+        type_vals = "int"
+    mat_min = np.min(mat)
+    i = 0
+    for ix in range(n_rows):
+        for iy in range(n_cols):
+            m = mat[ix, iy]
+            s = m - mat_min + 1
+            mat_arr[i, :] = np.array([ix, iy, m, s])
+            i += 1
+
+    mat_df = pd.DataFrame(mat_arr, columns=[str_rows, str_cols, "Value", "Size"])
+    if type_vals == "int":
+        mat_df = mat_df.astype(
+            dtype={str_rows: int, str_cols: int, "Value": int, "Size": float}
+        )
+    else:
+        mat_df = mat_df.astype(
+            dtype={str_rows: int, str_cols: int, "Value": float, "Size": float}
+        )
+    base = alt.Chart(mat_df).encode(
+        x=f"{str_rows}:O", y=alt.Y(f"{str_cols}:O", sort="descending")
+    )
+    mat_map = base.mark_circle(opacity=0.4).encode(
+        size=alt.Size(
+            "Size:Q",
+            legend=None,
+            scale=alt.Scale(range=[1000 * multiple, 10000 * multiple]),
+        )
+    )
+    text = base.mark_text(baseline="middle", fontSize=16).encode(
+        text=alt.Text("Value:Q", format=str_format),
+    )
+    if title is None:
+        both = (mat_map + text).properties(width=500, height=500)
+    else:
+        both = (mat_map + text).properties(title=title, width=400, height=400)
+
+    _maybe_save(both, save)
+    return both
+
+
 def alt_plot_fun(
     f: Callable,
     start: float,
